@@ -18,6 +18,7 @@ const zend_ast_kind ast_kinds[] = {
 	ZEND_AST_NAME_LIST,
 	ZEND_AST_TRAIT_ADAPTATIONS,
 	ZEND_AST_USE,
+	ZEND_AST_TYPE_UNION,
 	AST_NAME,
 	AST_CLOSURE_VAR,
 	AST_NULLABLE_TYPE,
@@ -118,6 +119,7 @@ const char *ast_kind_to_name(zend_ast_kind kind) {
 		case ZEND_AST_NAME_LIST: return "AST_NAME_LIST";
 		case ZEND_AST_TRAIT_ADAPTATIONS: return "AST_TRAIT_ADAPTATIONS";
 		case ZEND_AST_USE: return "AST_USE";
+		case ZEND_AST_TYPE_UNION: return "AST_TYPE_UNION";
 		case AST_NAME: return "AST_NAME";
 		case AST_CLOSURE_VAR: return "AST_CLOSURE_VAR";
 		case AST_NULLABLE_TYPE: return "AST_NULLABLE_TYPE";
@@ -668,6 +670,7 @@ void ast_register_kind_constants(INIT_FUNC_ARGS) {
 	REGISTER_NS_LONG_CONSTANT("ast", "AST_NAME_LIST", ZEND_AST_NAME_LIST, CONST_CS | CONST_PERSISTENT);
 	REGISTER_NS_LONG_CONSTANT("ast", "AST_TRAIT_ADAPTATIONS", ZEND_AST_TRAIT_ADAPTATIONS, CONST_CS | CONST_PERSISTENT);
 	REGISTER_NS_LONG_CONSTANT("ast", "AST_USE", ZEND_AST_USE, CONST_CS | CONST_PERSISTENT);
+	REGISTER_NS_LONG_CONSTANT("ast", "AST_TYPE_UNION", ZEND_AST_TYPE_UNION, CONST_CS | CONST_PERSISTENT);
 	REGISTER_NS_LONG_CONSTANT("ast", "AST_NAME", AST_NAME, CONST_CS | CONST_PERSISTENT);
 	REGISTER_NS_LONG_CONSTANT("ast", "AST_CLOSURE_VAR", AST_CLOSURE_VAR, CONST_CS | CONST_PERSISTENT);
 	REGISTER_NS_LONG_CONSTANT("ast", "AST_NULLABLE_TYPE", AST_NULLABLE_TYPE, CONST_CS | CONST_PERSISTENT);
