@@ -24,6 +24,7 @@ const AST_CLASS_CONST_DECL = 140;
 const AST_NAME_LIST = 141;
 const AST_TRAIT_ADAPTATIONS = 142;
 const AST_USE = 143;
+const AST_TYPE_UNION = 144;
 const AST_NAME = 2048;
 const AST_CLOSURE_VAR = 2049;
 const AST_NULLABLE_TYPE = 2050;
@@ -127,15 +128,16 @@ const CLASS_ANONYMOUS = 4;
 const PARAM_REF = 1;
 const PARAM_VARIADIC = 2;
 const TYPE_NULL = 1;
-const TYPE_BOOL = 16;
+const TYPE_FALSE = 2;
+const TYPE_BOOL = 18;
 const TYPE_LONG = 4;
 const TYPE_DOUBLE = 5;
 const TYPE_STRING = 6;
 const TYPE_ARRAY = 7;
 const TYPE_OBJECT = 8;
-const TYPE_CALLABLE = 17;
-const TYPE_VOID = 19;
-const TYPE_ITERABLE = 18;
+const TYPE_CALLABLE = 12;
+const TYPE_VOID = 14;
+const TYPE_ITERABLE = 13;
 const UNARY_BOOL_NOT = 14;
 const UNARY_BITWISE_NOT = 13;
 const UNARY_SILENCE = 260;
